/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleDataplexDatascanConfig extends cdktf.TerraformMetaArguments {
    /**
    * DataScan identifier. Must contain only lowercase letters, numbers and hyphens. Must start with a letter. Must end with a number or a letter.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#data_scan_id GoogleDataplexDatascan#data_scan_id}
    */
    readonly dataScanId: string;
    /**
    * Description of the scan.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#description GoogleDataplexDatascan#description}
    */
    readonly description?: string;
    /**
    * User friendly display name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#display_name GoogleDataplexDatascan#display_name}
    */
    readonly displayName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#id GoogleDataplexDatascan#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * User-defined labels for the scan. A list of key->value pairs.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#labels GoogleDataplexDatascan#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The location where the data scan should reside.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#location GoogleDataplexDatascan#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#project GoogleDataplexDatascan#project}
    */
    readonly project?: string;
    /**
    * data block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#data GoogleDataplexDatascan#data}
    */
    readonly data: GoogleDataplexDatascanData;
    /**
    * data_profile_spec block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#data_profile_spec GoogleDataplexDatascan#data_profile_spec}
    */
    readonly dataProfileSpec?: GoogleDataplexDatascanDataProfileSpec;
    /**
    * data_quality_spec block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#data_quality_spec GoogleDataplexDatascan#data_quality_spec}
    */
    readonly dataQualitySpec?: GoogleDataplexDatascanDataQualitySpec;
    /**
    * execution_spec block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#execution_spec GoogleDataplexDatascan#execution_spec}
    */
    readonly executionSpec: GoogleDataplexDatascanExecutionSpec;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#timeouts GoogleDataplexDatascan#timeouts}
    */
    readonly timeouts?: GoogleDataplexDatascanTimeouts;
}
export interface GoogleDataplexDatascanDataProfileResultProfileFieldsProfileDoubleProfile {
}
export declare function googleDataplexDatascanDataProfileResultProfileFieldsProfileDoubleProfileToTerraform(struct?: GoogleDataplexDatascanDataProfileResultProfileFieldsProfileDoubleProfile): any;
export declare class GoogleDataplexDatascanDataProfileResultProfileFieldsProfileDoubleProfileOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataplexDatascanDataProfileResultProfileFieldsProfileDoubleProfile | undefined;
    set internalValue(value: GoogleDataplexDatascanDataProfileResultProfileFieldsProfileDoubleProfile | undefined);
    get average(): number;
    get max(): string;
    get min(): string;
    get quartiles(): string;
    get standardDeviation(): number;
}
export declare class GoogleDataplexDatascanDataProfileResultProfileFieldsProfileDoubleProfileList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataplexDatascanDataProfileResultProfileFieldsProfileDoubleProfileOutputReference;
}
export interface GoogleDataplexDatascanDataProfileResultProfileFieldsProfileIntegerProfile {
}
export declare function googleDataplexDatascanDataProfileResultProfileFieldsProfileIntegerProfileToTerraform(struct?: GoogleDataplexDatascanDataProfileResultProfileFieldsProfileIntegerProfile): any;
export declare class GoogleDataplexDatascanDataProfileResultProfileFieldsProfileIntegerProfileOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataplexDatascanDataProfileResultProfileFieldsProfileIntegerProfile | undefined;
    set internalValue(value: GoogleDataplexDatascanDataProfileResultProfileFieldsProfileIntegerProfile | undefined);
    get average(): number;
    get max(): string;
    get min(): string;
    get quartiles(): string;
    get standardDeviation(): number;
}
export declare class GoogleDataplexDatascanDataProfileResultProfileFieldsProfileIntegerProfileList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataplexDatascanDataProfileResultProfileFieldsProfileIntegerProfileOutputReference;
}
export interface GoogleDataplexDatascanDataProfileResultProfileFieldsProfileStringProfile {
}
export declare function googleDataplexDatascanDataProfileResultProfileFieldsProfileStringProfileToTerraform(struct?: GoogleDataplexDatascanDataProfileResultProfileFieldsProfileStringProfile): any;
export declare class GoogleDataplexDatascanDataProfileResultProfileFieldsProfileStringProfileOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataplexDatascanDataProfileResultProfileFieldsProfileStringProfile | undefined;
    set internalValue(value: GoogleDataplexDatascanDataProfileResultProfileFieldsProfileStringProfile | undefined);
    get averageLength(): number;
    get maxLength(): string;
    get minLength(): string;
}
export declare class GoogleDataplexDatascanDataProfileResultProfileFieldsProfileStringProfileList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataplexDatascanDataProfileResultProfileFieldsProfileStringProfileOutputReference;
}
export interface GoogleDataplexDatascanDataProfileResultProfileFieldsProfileTopNValues {
}
export declare function googleDataplexDatascanDataProfileResultProfileFieldsProfileTopNValuesToTerraform(struct?: GoogleDataplexDatascanDataProfileResultProfileFieldsProfileTopNValues): any;
export declare class GoogleDataplexDatascanDataProfileResultProfileFieldsProfileTopNValuesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataplexDatascanDataProfileResultProfileFieldsProfileTopNValues | undefined;
    set internalValue(value: GoogleDataplexDatascanDataProfileResultProfileFieldsProfileTopNValues | undefined);
    get count(): string;
    get value(): string;
}
export declare class GoogleDataplexDatascanDataProfileResultProfileFieldsProfileTopNValuesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataplexDatascanDataProfileResultProfileFieldsProfileTopNValuesOutputReference;
}
export interface GoogleDataplexDatascanDataProfileResultProfileFieldsProfile {
}
export declare function googleDataplexDatascanDataProfileResultProfileFieldsProfileToTerraform(struct?: GoogleDataplexDatascanDataProfileResultProfileFieldsProfile): any;
export declare class GoogleDataplexDatascanDataProfileResultProfileFieldsProfileOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataplexDatascanDataProfileResultProfileFieldsProfile | undefined;
    set internalValue(value: GoogleDataplexDatascanDataProfileResultProfileFieldsProfile | undefined);
    get distinctRatio(): number;
    private _doubleProfile;
    get doubleProfile(): GoogleDataplexDatascanDataProfileResultProfileFieldsProfileDoubleProfileList;
    private _integerProfile;
    get integerProfile(): GoogleDataplexDatascanDataProfileResultProfileFieldsProfileIntegerProfileList;
    get nullRatio(): number;
    private _stringProfile;
    get stringProfile(): GoogleDataplexDatascanDataProfileResultProfileFieldsProfileStringProfileList;
    private _topNValues;
    get topNValues(): GoogleDataplexDatascanDataProfileResultProfileFieldsProfileTopNValuesList;
}
export declare class GoogleDataplexDatascanDataProfileResultProfileFieldsProfileList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataplexDatascanDataProfileResultProfileFieldsProfileOutputReference;
}
export interface GoogleDataplexDatascanDataProfileResultProfileFields {
}
export declare function googleDataplexDatascanDataProfileResultProfileFieldsToTerraform(struct?: GoogleDataplexDatascanDataProfileResultProfileFields): any;
export declare class GoogleDataplexDatascanDataProfileResultProfileFieldsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataplexDatascanDataProfileResultProfileFields | undefined;
    set internalValue(value: GoogleDataplexDatascanDataProfileResultProfileFields | undefined);
    get mode(): string;
    get name(): string;
    private _profile;
    get profile(): GoogleDataplexDatascanDataProfileResultProfileFieldsProfileList;
    get type(): string;
}
export declare class GoogleDataplexDatascanDataProfileResultProfileFieldsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataplexDatascanDataProfileResultProfileFieldsOutputReference;
}
export interface GoogleDataplexDatascanDataProfileResultProfile {
}
export declare function googleDataplexDatascanDataProfileResultProfileToTerraform(struct?: GoogleDataplexDatascanDataProfileResultProfile): any;
export declare class GoogleDataplexDatascanDataProfileResultProfileOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataplexDatascanDataProfileResultProfile | undefined;
    set internalValue(value: GoogleDataplexDatascanDataProfileResultProfile | undefined);
    private _fields;
    get fields(): GoogleDataplexDatascanDataProfileResultProfileFieldsList;
}
export declare class GoogleDataplexDatascanDataProfileResultProfileList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataplexDatascanDataProfileResultProfileOutputReference;
}
export interface GoogleDataplexDatascanDataProfileResultScannedDataIncrementalField {
}
export declare function googleDataplexDatascanDataProfileResultScannedDataIncrementalFieldToTerraform(struct?: GoogleDataplexDatascanDataProfileResultScannedDataIncrementalField): any;
export declare class GoogleDataplexDatascanDataProfileResultScannedDataIncrementalFieldOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataplexDatascanDataProfileResultScannedDataIncrementalField | undefined;
    set internalValue(value: GoogleDataplexDatascanDataProfileResultScannedDataIncrementalField | undefined);
    get end(): string;
    get field(): string;
    get start(): string;
}
export declare class GoogleDataplexDatascanDataProfileResultScannedDataIncrementalFieldList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataplexDatascanDataProfileResultScannedDataIncrementalFieldOutputReference;
}
export interface GoogleDataplexDatascanDataProfileResultScannedData {
}
export declare function googleDataplexDatascanDataProfileResultScannedDataToTerraform(struct?: GoogleDataplexDatascanDataProfileResultScannedData): any;
export declare class GoogleDataplexDatascanDataProfileResultScannedDataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataplexDatascanDataProfileResultScannedData | undefined;
    set internalValue(value: GoogleDataplexDatascanDataProfileResultScannedData | undefined);
    private _incrementalField;
    get incrementalField(): GoogleDataplexDatascanDataProfileResultScannedDataIncrementalFieldList;
}
export declare class GoogleDataplexDatascanDataProfileResultScannedDataList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataplexDatascanDataProfileResultScannedDataOutputReference;
}
export interface GoogleDataplexDatascanDataProfileResult {
}
export declare function googleDataplexDatascanDataProfileResultToTerraform(struct?: GoogleDataplexDatascanDataProfileResult): any;
export declare class GoogleDataplexDatascanDataProfileResultOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataplexDatascanDataProfileResult | undefined;
    set internalValue(value: GoogleDataplexDatascanDataProfileResult | undefined);
    private _profile;
    get profile(): GoogleDataplexDatascanDataProfileResultProfileList;
    get rowCount(): string;
    private _scannedData;
    get scannedData(): GoogleDataplexDatascanDataProfileResultScannedDataList;
}
export declare class GoogleDataplexDatascanDataProfileResultList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataplexDatascanDataProfileResultOutputReference;
}
export interface GoogleDataplexDatascanDataQualityResultDimensions {
}
export declare function googleDataplexDatascanDataQualityResultDimensionsToTerraform(struct?: GoogleDataplexDatascanDataQualityResultDimensions): any;
export declare class GoogleDataplexDatascanDataQualityResultDimensionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataplexDatascanDataQualityResultDimensions | undefined;
    set internalValue(value: GoogleDataplexDatascanDataQualityResultDimensions | undefined);
    get passed(): cdktf.IResolvable;
}
export declare class GoogleDataplexDatascanDataQualityResultDimensionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataplexDatascanDataQualityResultDimensionsOutputReference;
}
export interface GoogleDataplexDatascanDataQualityResultRulesRuleNonNullExpectation {
}
export declare function googleDataplexDatascanDataQualityResultRulesRuleNonNullExpectationToTerraform(struct?: GoogleDataplexDatascanDataQualityResultRulesRuleNonNullExpectation): any;
export declare class GoogleDataplexDatascanDataQualityResultRulesRuleNonNullExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataplexDatascanDataQualityResultRulesRuleNonNullExpectation | undefined;
    set internalValue(value: GoogleDataplexDatascanDataQualityResultRulesRuleNonNullExpectation | undefined);
}
export declare class GoogleDataplexDatascanDataQualityResultRulesRuleNonNullExpectationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataplexDatascanDataQualityResultRulesRuleNonNullExpectationOutputReference;
}
export interface GoogleDataplexDatascanDataQualityResultRulesRuleRangeExpectation {
}
export declare function googleDataplexDatascanDataQualityResultRulesRuleRangeExpectationToTerraform(struct?: GoogleDataplexDatascanDataQualityResultRulesRuleRangeExpectation): any;
export declare class GoogleDataplexDatascanDataQualityResultRulesRuleRangeExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataplexDatascanDataQualityResultRulesRuleRangeExpectation | undefined;
    set internalValue(value: GoogleDataplexDatascanDataQualityResultRulesRuleRangeExpectation | undefined);
    get maxValue(): string;
    get minValue(): string;
    get strictMaxEnabled(): cdktf.IResolvable;
    get strictMinEnabled(): cdktf.IResolvable;
}
export declare class GoogleDataplexDatascanDataQualityResultRulesRuleRangeExpectationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataplexDatascanDataQualityResultRulesRuleRangeExpectationOutputReference;
}
export interface GoogleDataplexDatascanDataQualityResultRulesRuleRegexExpectation {
}
export declare function googleDataplexDatascanDataQualityResultRulesRuleRegexExpectationToTerraform(struct?: GoogleDataplexDatascanDataQualityResultRulesRuleRegexExpectation): any;
export declare class GoogleDataplexDatascanDataQualityResultRulesRuleRegexExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataplexDatascanDataQualityResultRulesRuleRegexExpectation | undefined;
    set internalValue(value: GoogleDataplexDatascanDataQualityResultRulesRuleRegexExpectation | undefined);
    get regex(): string;
}
export declare class GoogleDataplexDatascanDataQualityResultRulesRuleRegexExpectationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataplexDatascanDataQualityResultRulesRuleRegexExpectationOutputReference;
}
export interface GoogleDataplexDatascanDataQualityResultRulesRuleRowConditionExpectation {
}
export declare function googleDataplexDatascanDataQualityResultRulesRuleRowConditionExpectationToTerraform(struct?: GoogleDataplexDatascanDataQualityResultRulesRuleRowConditionExpectation): any;
export declare class GoogleDataplexDatascanDataQualityResultRulesRuleRowConditionExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataplexDatascanDataQualityResultRulesRuleRowConditionExpectation | undefined;
    set internalValue(value: GoogleDataplexDatascanDataQualityResultRulesRuleRowConditionExpectation | undefined);
    get sqlExpression(): string;
}
export declare class GoogleDataplexDatascanDataQualityResultRulesRuleRowConditionExpectationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataplexDatascanDataQualityResultRulesRuleRowConditionExpectationOutputReference;
}
export interface GoogleDataplexDatascanDataQualityResultRulesRuleSetExpectation {
}
export declare function googleDataplexDatascanDataQualityResultRulesRuleSetExpectationToTerraform(struct?: GoogleDataplexDatascanDataQualityResultRulesRuleSetExpectation): any;
export declare class GoogleDataplexDatascanDataQualityResultRulesRuleSetExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataplexDatascanDataQualityResultRulesRuleSetExpectation | undefined;
    set internalValue(value: GoogleDataplexDatascanDataQualityResultRulesRuleSetExpectation | undefined);
    get values(): string[];
}
export declare class GoogleDataplexDatascanDataQualityResultRulesRuleSetExpectationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataplexDatascanDataQualityResultRulesRuleSetExpectationOutputReference;
}
export interface GoogleDataplexDatascanDataQualityResultRulesRuleStatisticRangeExpectation {
}
export declare function googleDataplexDatascanDataQualityResultRulesRuleStatisticRangeExpectationToTerraform(struct?: GoogleDataplexDatascanDataQualityResultRulesRuleStatisticRangeExpectation): any;
export declare class GoogleDataplexDatascanDataQualityResultRulesRuleStatisticRangeExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataplexDatascanDataQualityResultRulesRuleStatisticRangeExpectation | undefined;
    set internalValue(value: GoogleDataplexDatascanDataQualityResultRulesRuleStatisticRangeExpectation | undefined);
    get maxValue(): string;
    get minValue(): string;
    get statistic(): string;
    get strictMaxEnabled(): cdktf.IResolvable;
    get strictMinEnabled(): cdktf.IResolvable;
}
export declare class GoogleDataplexDatascanDataQualityResultRulesRuleStatisticRangeExpectationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataplexDatascanDataQualityResultRulesRuleStatisticRangeExpectationOutputReference;
}
export interface GoogleDataplexDatascanDataQualityResultRulesRuleTableConditionExpectation {
}
export declare function googleDataplexDatascanDataQualityResultRulesRuleTableConditionExpectationToTerraform(struct?: GoogleDataplexDatascanDataQualityResultRulesRuleTableConditionExpectation): any;
export declare class GoogleDataplexDatascanDataQualityResultRulesRuleTableConditionExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataplexDatascanDataQualityResultRulesRuleTableConditionExpectation | undefined;
    set internalValue(value: GoogleDataplexDatascanDataQualityResultRulesRuleTableConditionExpectation | undefined);
    get sqlExpression(): string;
}
export declare class GoogleDataplexDatascanDataQualityResultRulesRuleTableConditionExpectationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataplexDatascanDataQualityResultRulesRuleTableConditionExpectationOutputReference;
}
export interface GoogleDataplexDatascanDataQualityResultRulesRuleUniquenessExpectation {
}
export declare function googleDataplexDatascanDataQualityResultRulesRuleUniquenessExpectationToTerraform(struct?: GoogleDataplexDatascanDataQualityResultRulesRuleUniquenessExpectation): any;
export declare class GoogleDataplexDatascanDataQualityResultRulesRuleUniquenessExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataplexDatascanDataQualityResultRulesRuleUniquenessExpectation | undefined;
    set internalValue(value: GoogleDataplexDatascanDataQualityResultRulesRuleUniquenessExpectation | undefined);
}
export declare class GoogleDataplexDatascanDataQualityResultRulesRuleUniquenessExpectationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataplexDatascanDataQualityResultRulesRuleUniquenessExpectationOutputReference;
}
export interface GoogleDataplexDatascanDataQualityResultRulesRule {
}
export declare function googleDataplexDatascanDataQualityResultRulesRuleToTerraform(struct?: GoogleDataplexDatascanDataQualityResultRulesRule): any;
export declare class GoogleDataplexDatascanDataQualityResultRulesRuleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataplexDatascanDataQualityResultRulesRule | undefined;
    set internalValue(value: GoogleDataplexDatascanDataQualityResultRulesRule | undefined);
    get column(): string;
    get dimension(): string;
    get ignoreNull(): cdktf.IResolvable;
    private _nonNullExpectation;
    get nonNullExpectation(): GoogleDataplexDatascanDataQualityResultRulesRuleNonNullExpectationList;
    private _rangeExpectation;
    get rangeExpectation(): GoogleDataplexDatascanDataQualityResultRulesRuleRangeExpectationList;
    private _regexExpectation;
    get regexExpectation(): GoogleDataplexDatascanDataQualityResultRulesRuleRegexExpectationList;
    private _rowConditionExpectation;
    get rowConditionExpectation(): GoogleDataplexDatascanDataQualityResultRulesRuleRowConditionExpectationList;
    private _setExpectation;
    get setExpectation(): GoogleDataplexDatascanDataQualityResultRulesRuleSetExpectationList;
    private _statisticRangeExpectation;
    get statisticRangeExpectation(): GoogleDataplexDatascanDataQualityResultRulesRuleStatisticRangeExpectationList;
    private _tableConditionExpectation;
    get tableConditionExpectation(): GoogleDataplexDatascanDataQualityResultRulesRuleTableConditionExpectationList;
    get threshold(): number;
    private _uniquenessExpectation;
    get uniquenessExpectation(): GoogleDataplexDatascanDataQualityResultRulesRuleUniquenessExpectationList;
}
export declare class GoogleDataplexDatascanDataQualityResultRulesRuleList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataplexDatascanDataQualityResultRulesRuleOutputReference;
}
export interface GoogleDataplexDatascanDataQualityResultRules {
}
export declare function googleDataplexDatascanDataQualityResultRulesToTerraform(struct?: GoogleDataplexDatascanDataQualityResultRules): any;
export declare class GoogleDataplexDatascanDataQualityResultRulesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataplexDatascanDataQualityResultRules | undefined;
    set internalValue(value: GoogleDataplexDatascanDataQualityResultRules | undefined);
    get evaluatedCount(): string;
    get failingRowsQuery(): string;
    get nullCount(): string;
    get passRatio(): number;
    get passed(): cdktf.IResolvable;
    get passedCount(): string;
    private _rule;
    get rule(): GoogleDataplexDatascanDataQualityResultRulesRuleList;
}
export declare class GoogleDataplexDatascanDataQualityResultRulesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataplexDatascanDataQualityResultRulesOutputReference;
}
export interface GoogleDataplexDatascanDataQualityResultScannedDataIncrementalField {
}
export declare function googleDataplexDatascanDataQualityResultScannedDataIncrementalFieldToTerraform(struct?: GoogleDataplexDatascanDataQualityResultScannedDataIncrementalField): any;
export declare class GoogleDataplexDatascanDataQualityResultScannedDataIncrementalFieldOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataplexDatascanDataQualityResultScannedDataIncrementalField | undefined;
    set internalValue(value: GoogleDataplexDatascanDataQualityResultScannedDataIncrementalField | undefined);
    get end(): string;
    get field(): string;
    get start(): string;
}
export declare class GoogleDataplexDatascanDataQualityResultScannedDataIncrementalFieldList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataplexDatascanDataQualityResultScannedDataIncrementalFieldOutputReference;
}
export interface GoogleDataplexDatascanDataQualityResultScannedData {
}
export declare function googleDataplexDatascanDataQualityResultScannedDataToTerraform(struct?: GoogleDataplexDatascanDataQualityResultScannedData): any;
export declare class GoogleDataplexDatascanDataQualityResultScannedDataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataplexDatascanDataQualityResultScannedData | undefined;
    set internalValue(value: GoogleDataplexDatascanDataQualityResultScannedData | undefined);
    private _incrementalField;
    get incrementalField(): GoogleDataplexDatascanDataQualityResultScannedDataIncrementalFieldList;
}
export declare class GoogleDataplexDatascanDataQualityResultScannedDataList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataplexDatascanDataQualityResultScannedDataOutputReference;
}
export interface GoogleDataplexDatascanDataQualityResult {
}
export declare function googleDataplexDatascanDataQualityResultToTerraform(struct?: GoogleDataplexDatascanDataQualityResult): any;
export declare class GoogleDataplexDatascanDataQualityResultOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataplexDatascanDataQualityResult | undefined;
    set internalValue(value: GoogleDataplexDatascanDataQualityResult | undefined);
    private _dimensions;
    get dimensions(): GoogleDataplexDatascanDataQualityResultDimensionsList;
    get passed(): cdktf.IResolvable;
    get rowCount(): string;
    private _rules;
    get rules(): GoogleDataplexDatascanDataQualityResultRulesList;
    private _scannedData;
    get scannedData(): GoogleDataplexDatascanDataQualityResultScannedDataList;
}
export declare class GoogleDataplexDatascanDataQualityResultList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataplexDatascanDataQualityResultOutputReference;
}
export interface GoogleDataplexDatascanExecutionStatus {
}
export declare function googleDataplexDatascanExecutionStatusToTerraform(struct?: GoogleDataplexDatascanExecutionStatus): any;
export declare class GoogleDataplexDatascanExecutionStatusOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataplexDatascanExecutionStatus | undefined;
    set internalValue(value: GoogleDataplexDatascanExecutionStatus | undefined);
    get latestJobEndTime(): string;
    get latestJobStartTime(): string;
}
export declare class GoogleDataplexDatascanExecutionStatusList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataplexDatascanExecutionStatusOutputReference;
}
export interface GoogleDataplexDatascanData {
    /**
    * The Dataplex entity that represents the data source(e.g. BigQuery table) for Datascan.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#entity GoogleDataplexDatascan#entity}
    */
    readonly entity?: string;
    /**
    * The service-qualified full resource name of the cloud resource for a DataScan job to scan against. The field could be:
  (Cloud Storage bucket for DataDiscoveryScan)BigQuery table of type "TABLE" for DataProfileScan/DataQualityScan.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#resource GoogleDataplexDatascan#resource}
    */
    readonly resource?: string;
}
export declare function googleDataplexDatascanDataToTerraform(struct?: GoogleDataplexDatascanDataOutputReference | GoogleDataplexDatascanData): any;
export declare class GoogleDataplexDatascanDataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataplexDatascanData | undefined;
    set internalValue(value: GoogleDataplexDatascanData | undefined);
    private _entity?;
    get entity(): string;
    set entity(value: string);
    resetEntity(): void;
    get entityInput(): string | undefined;
    private _resource?;
    get resource(): string;
    set resource(value: string);
    resetResource(): void;
    get resourceInput(): string | undefined;
}
export interface GoogleDataplexDatascanDataProfileSpec {
    /**
    * A filter applied to all rows in a single DataScan job. The filter needs to be a valid SQL expression for a WHERE clause in BigQuery standard SQL syntax. Example: col1 >= 0 AND col2 < 10
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#row_filter GoogleDataplexDatascan#row_filter}
    */
    readonly rowFilter?: string;
    /**
    * The percentage of the records to be selected from the dataset for DataScan.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#sampling_percent GoogleDataplexDatascan#sampling_percent}
    */
    readonly samplingPercent?: number;
}
export declare function googleDataplexDatascanDataProfileSpecToTerraform(struct?: GoogleDataplexDatascanDataProfileSpecOutputReference | GoogleDataplexDatascanDataProfileSpec): any;
export declare class GoogleDataplexDatascanDataProfileSpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataplexDatascanDataProfileSpec | undefined;
    set internalValue(value: GoogleDataplexDatascanDataProfileSpec | undefined);
    private _rowFilter?;
    get rowFilter(): string;
    set rowFilter(value: string);
    resetRowFilter(): void;
    get rowFilterInput(): string | undefined;
    private _samplingPercent?;
    get samplingPercent(): number;
    set samplingPercent(value: number);
    resetSamplingPercent(): void;
    get samplingPercentInput(): number | undefined;
}
export interface GoogleDataplexDatascanDataQualitySpecRulesNonNullExpectation {
}
export declare function googleDataplexDatascanDataQualitySpecRulesNonNullExpectationToTerraform(struct?: GoogleDataplexDatascanDataQualitySpecRulesNonNullExpectationOutputReference | GoogleDataplexDatascanDataQualitySpecRulesNonNullExpectation): any;
export declare class GoogleDataplexDatascanDataQualitySpecRulesNonNullExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataplexDatascanDataQualitySpecRulesNonNullExpectation | undefined;
    set internalValue(value: GoogleDataplexDatascanDataQualitySpecRulesNonNullExpectation | undefined);
}
export interface GoogleDataplexDatascanDataQualitySpecRulesRangeExpectation {
    /**
    * The maximum column value allowed for a row to pass this validation. At least one of minValue and maxValue need to be provided.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#max_value GoogleDataplexDatascan#max_value}
    */
    readonly maxValue?: string;
    /**
    * The minimum column value allowed for a row to pass this validation. At least one of minValue and maxValue need to be provided.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#min_value GoogleDataplexDatascan#min_value}
    */
    readonly minValue?: string;
    /**
    * Whether each value needs to be strictly lesser than ('<') the maximum, or if equality is allowed.
  Only relevant if a maxValue has been defined. Default = false.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#strict_max_enabled GoogleDataplexDatascan#strict_max_enabled}
    */
    readonly strictMaxEnabled?: boolean | cdktf.IResolvable;
    /**
    * Whether each value needs to be strictly greater than ('>') the minimum, or if equality is allowed.
  Only relevant if a minValue has been defined. Default = false.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#strict_min_enabled GoogleDataplexDatascan#strict_min_enabled}
    */
    readonly strictMinEnabled?: boolean | cdktf.IResolvable;
}
export declare function googleDataplexDatascanDataQualitySpecRulesRangeExpectationToTerraform(struct?: GoogleDataplexDatascanDataQualitySpecRulesRangeExpectationOutputReference | GoogleDataplexDatascanDataQualitySpecRulesRangeExpectation): any;
export declare class GoogleDataplexDatascanDataQualitySpecRulesRangeExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataplexDatascanDataQualitySpecRulesRangeExpectation | undefined;
    set internalValue(value: GoogleDataplexDatascanDataQualitySpecRulesRangeExpectation | undefined);
    private _maxValue?;
    get maxValue(): string;
    set maxValue(value: string);
    resetMaxValue(): void;
    get maxValueInput(): string | undefined;
    private _minValue?;
    get minValue(): string;
    set minValue(value: string);
    resetMinValue(): void;
    get minValueInput(): string | undefined;
    private _strictMaxEnabled?;
    get strictMaxEnabled(): boolean | cdktf.IResolvable;
    set strictMaxEnabled(value: boolean | cdktf.IResolvable);
    resetStrictMaxEnabled(): void;
    get strictMaxEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _strictMinEnabled?;
    get strictMinEnabled(): boolean | cdktf.IResolvable;
    set strictMinEnabled(value: boolean | cdktf.IResolvable);
    resetStrictMinEnabled(): void;
    get strictMinEnabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface GoogleDataplexDatascanDataQualitySpecRulesRegexExpectation {
    /**
    * A regular expression the column value is expected to match.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#regex GoogleDataplexDatascan#regex}
    */
    readonly regex: string;
}
export declare function googleDataplexDatascanDataQualitySpecRulesRegexExpectationToTerraform(struct?: GoogleDataplexDatascanDataQualitySpecRulesRegexExpectationOutputReference | GoogleDataplexDatascanDataQualitySpecRulesRegexExpectation): any;
export declare class GoogleDataplexDatascanDataQualitySpecRulesRegexExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataplexDatascanDataQualitySpecRulesRegexExpectation | undefined;
    set internalValue(value: GoogleDataplexDatascanDataQualitySpecRulesRegexExpectation | undefined);
    private _regex?;
    get regex(): string;
    set regex(value: string);
    get regexInput(): string | undefined;
}
export interface GoogleDataplexDatascanDataQualitySpecRulesRowConditionExpectation {
    /**
    * The SQL expression.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#sql_expression GoogleDataplexDatascan#sql_expression}
    */
    readonly sqlExpression: string;
}
export declare function googleDataplexDatascanDataQualitySpecRulesRowConditionExpectationToTerraform(struct?: GoogleDataplexDatascanDataQualitySpecRulesRowConditionExpectationOutputReference | GoogleDataplexDatascanDataQualitySpecRulesRowConditionExpectation): any;
export declare class GoogleDataplexDatascanDataQualitySpecRulesRowConditionExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataplexDatascanDataQualitySpecRulesRowConditionExpectation | undefined;
    set internalValue(value: GoogleDataplexDatascanDataQualitySpecRulesRowConditionExpectation | undefined);
    private _sqlExpression?;
    get sqlExpression(): string;
    set sqlExpression(value: string);
    get sqlExpressionInput(): string | undefined;
}
export interface GoogleDataplexDatascanDataQualitySpecRulesSetExpectation {
    /**
    * Expected values for the column value.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#values GoogleDataplexDatascan#values}
    */
    readonly values: string[];
}
export declare function googleDataplexDatascanDataQualitySpecRulesSetExpectationToTerraform(struct?: GoogleDataplexDatascanDataQualitySpecRulesSetExpectationOutputReference | GoogleDataplexDatascanDataQualitySpecRulesSetExpectation): any;
export declare class GoogleDataplexDatascanDataQualitySpecRulesSetExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataplexDatascanDataQualitySpecRulesSetExpectation | undefined;
    set internalValue(value: GoogleDataplexDatascanDataQualitySpecRulesSetExpectation | undefined);
    private _values?;
    get values(): string[];
    set values(value: string[]);
    get valuesInput(): string[] | undefined;
}
export interface GoogleDataplexDatascanDataQualitySpecRulesStatisticRangeExpectation {
    /**
    * The maximum column statistic value allowed for a row to pass this validation.
  At least one of minValue and maxValue need to be provided.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#max_value GoogleDataplexDatascan#max_value}
    */
    readonly maxValue?: string;
    /**
    * The minimum column statistic value allowed for a row to pass this validation.
  At least one of minValue and maxValue need to be provided.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#min_value GoogleDataplexDatascan#min_value}
    */
    readonly minValue?: string;
    /**
    * column statistics. Possible values: ["STATISTIC_UNDEFINED", "MEAN", "MIN", "MAX"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#statistic GoogleDataplexDatascan#statistic}
    */
    readonly statistic: string;
    /**
    * Whether column statistic needs to be strictly lesser than ('<') the maximum, or if equality is allowed.
  Only relevant if a maxValue has been defined. Default = false.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#strict_max_enabled GoogleDataplexDatascan#strict_max_enabled}
    */
    readonly strictMaxEnabled?: boolean | cdktf.IResolvable;
    /**
    * Whether column statistic needs to be strictly greater than ('>') the minimum, or if equality is allowed.
  Only relevant if a minValue has been defined. Default = false.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#strict_min_enabled GoogleDataplexDatascan#strict_min_enabled}
    */
    readonly strictMinEnabled?: boolean | cdktf.IResolvable;
}
export declare function googleDataplexDatascanDataQualitySpecRulesStatisticRangeExpectationToTerraform(struct?: GoogleDataplexDatascanDataQualitySpecRulesStatisticRangeExpectationOutputReference | GoogleDataplexDatascanDataQualitySpecRulesStatisticRangeExpectation): any;
export declare class GoogleDataplexDatascanDataQualitySpecRulesStatisticRangeExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataplexDatascanDataQualitySpecRulesStatisticRangeExpectation | undefined;
    set internalValue(value: GoogleDataplexDatascanDataQualitySpecRulesStatisticRangeExpectation | undefined);
    private _maxValue?;
    get maxValue(): string;
    set maxValue(value: string);
    resetMaxValue(): void;
    get maxValueInput(): string | undefined;
    private _minValue?;
    get minValue(): string;
    set minValue(value: string);
    resetMinValue(): void;
    get minValueInput(): string | undefined;
    private _statistic?;
    get statistic(): string;
    set statistic(value: string);
    get statisticInput(): string | undefined;
    private _strictMaxEnabled?;
    get strictMaxEnabled(): boolean | cdktf.IResolvable;
    set strictMaxEnabled(value: boolean | cdktf.IResolvable);
    resetStrictMaxEnabled(): void;
    get strictMaxEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _strictMinEnabled?;
    get strictMinEnabled(): boolean | cdktf.IResolvable;
    set strictMinEnabled(value: boolean | cdktf.IResolvable);
    resetStrictMinEnabled(): void;
    get strictMinEnabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface GoogleDataplexDatascanDataQualitySpecRulesTableConditionExpectation {
    /**
    * The SQL expression.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#sql_expression GoogleDataplexDatascan#sql_expression}
    */
    readonly sqlExpression: string;
}
export declare function googleDataplexDatascanDataQualitySpecRulesTableConditionExpectationToTerraform(struct?: GoogleDataplexDatascanDataQualitySpecRulesTableConditionExpectationOutputReference | GoogleDataplexDatascanDataQualitySpecRulesTableConditionExpectation): any;
export declare class GoogleDataplexDatascanDataQualitySpecRulesTableConditionExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataplexDatascanDataQualitySpecRulesTableConditionExpectation | undefined;
    set internalValue(value: GoogleDataplexDatascanDataQualitySpecRulesTableConditionExpectation | undefined);
    private _sqlExpression?;
    get sqlExpression(): string;
    set sqlExpression(value: string);
    get sqlExpressionInput(): string | undefined;
}
export interface GoogleDataplexDatascanDataQualitySpecRulesUniquenessExpectation {
}
export declare function googleDataplexDatascanDataQualitySpecRulesUniquenessExpectationToTerraform(struct?: GoogleDataplexDatascanDataQualitySpecRulesUniquenessExpectationOutputReference | GoogleDataplexDatascanDataQualitySpecRulesUniquenessExpectation): any;
export declare class GoogleDataplexDatascanDataQualitySpecRulesUniquenessExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataplexDatascanDataQualitySpecRulesUniquenessExpectation | undefined;
    set internalValue(value: GoogleDataplexDatascanDataQualitySpecRulesUniquenessExpectation | undefined);
}
export interface GoogleDataplexDatascanDataQualitySpecRules {
    /**
    * The unnested column which this rule is evaluated against.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#column GoogleDataplexDatascan#column}
    */
    readonly column?: string;
    /**
    * The dimension a rule belongs to. Results are also aggregated at the dimension level. Supported dimensions are ["COMPLETENESS", "ACCURACY", "CONSISTENCY", "VALIDITY", "UNIQUENESS", "INTEGRITY"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#dimension GoogleDataplexDatascan#dimension}
    */
    readonly dimension: string;
    /**
    * Rows with null values will automatically fail a rule, unless ignoreNull is true. In that case, such null rows are trivially considered passing. Only applicable to ColumnMap rules.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#ignore_null GoogleDataplexDatascan#ignore_null}
    */
    readonly ignoreNull?: boolean | cdktf.IResolvable;
    /**
    * The minimum ratio of passing_rows / total_rows required to pass this rule, with a range of [0.0, 1.0]. 0 indicates default value (i.e. 1.0).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#threshold GoogleDataplexDatascan#threshold}
    */
    readonly threshold?: number;
    /**
    * non_null_expectation block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#non_null_expectation GoogleDataplexDatascan#non_null_expectation}
    */
    readonly nonNullExpectation?: GoogleDataplexDatascanDataQualitySpecRulesNonNullExpectation;
    /**
    * range_expectation block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#range_expectation GoogleDataplexDatascan#range_expectation}
    */
    readonly rangeExpectation?: GoogleDataplexDatascanDataQualitySpecRulesRangeExpectation;
    /**
    * regex_expectation block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#regex_expectation GoogleDataplexDatascan#regex_expectation}
    */
    readonly regexExpectation?: GoogleDataplexDatascanDataQualitySpecRulesRegexExpectation;
    /**
    * row_condition_expectation block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#row_condition_expectation GoogleDataplexDatascan#row_condition_expectation}
    */
    readonly rowConditionExpectation?: GoogleDataplexDatascanDataQualitySpecRulesRowConditionExpectation;
    /**
    * set_expectation block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#set_expectation GoogleDataplexDatascan#set_expectation}
    */
    readonly setExpectation?: GoogleDataplexDatascanDataQualitySpecRulesSetExpectation;
    /**
    * statistic_range_expectation block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#statistic_range_expectation GoogleDataplexDatascan#statistic_range_expectation}
    */
    readonly statisticRangeExpectation?: GoogleDataplexDatascanDataQualitySpecRulesStatisticRangeExpectation;
    /**
    * table_condition_expectation block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#table_condition_expectation GoogleDataplexDatascan#table_condition_expectation}
    */
    readonly tableConditionExpectation?: GoogleDataplexDatascanDataQualitySpecRulesTableConditionExpectation;
    /**
    * uniqueness_expectation block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#uniqueness_expectation GoogleDataplexDatascan#uniqueness_expectation}
    */
    readonly uniquenessExpectation?: GoogleDataplexDatascanDataQualitySpecRulesUniquenessExpectation;
}
export declare function googleDataplexDatascanDataQualitySpecRulesToTerraform(struct?: GoogleDataplexDatascanDataQualitySpecRules | cdktf.IResolvable): any;
export declare class GoogleDataplexDatascanDataQualitySpecRulesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataplexDatascanDataQualitySpecRules | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleDataplexDatascanDataQualitySpecRules | cdktf.IResolvable | undefined);
    private _column?;
    get column(): string;
    set column(value: string);
    resetColumn(): void;
    get columnInput(): string | undefined;
    private _dimension?;
    get dimension(): string;
    set dimension(value: string);
    get dimensionInput(): string | undefined;
    private _ignoreNull?;
    get ignoreNull(): boolean | cdktf.IResolvable;
    set ignoreNull(value: boolean | cdktf.IResolvable);
    resetIgnoreNull(): void;
    get ignoreNullInput(): boolean | cdktf.IResolvable | undefined;
    private _threshold?;
    get threshold(): number;
    set threshold(value: number);
    resetThreshold(): void;
    get thresholdInput(): number | undefined;
    private _nonNullExpectation;
    get nonNullExpectation(): GoogleDataplexDatascanDataQualitySpecRulesNonNullExpectationOutputReference;
    putNonNullExpectation(value: GoogleDataplexDatascanDataQualitySpecRulesNonNullExpectation): void;
    resetNonNullExpectation(): void;
    get nonNullExpectationInput(): GoogleDataplexDatascanDataQualitySpecRulesNonNullExpectation | undefined;
    private _rangeExpectation;
    get rangeExpectation(): GoogleDataplexDatascanDataQualitySpecRulesRangeExpectationOutputReference;
    putRangeExpectation(value: GoogleDataplexDatascanDataQualitySpecRulesRangeExpectation): void;
    resetRangeExpectation(): void;
    get rangeExpectationInput(): GoogleDataplexDatascanDataQualitySpecRulesRangeExpectation | undefined;
    private _regexExpectation;
    get regexExpectation(): GoogleDataplexDatascanDataQualitySpecRulesRegexExpectationOutputReference;
    putRegexExpectation(value: GoogleDataplexDatascanDataQualitySpecRulesRegexExpectation): void;
    resetRegexExpectation(): void;
    get regexExpectationInput(): GoogleDataplexDatascanDataQualitySpecRulesRegexExpectation | undefined;
    private _rowConditionExpectation;
    get rowConditionExpectation(): GoogleDataplexDatascanDataQualitySpecRulesRowConditionExpectationOutputReference;
    putRowConditionExpectation(value: GoogleDataplexDatascanDataQualitySpecRulesRowConditionExpectation): void;
    resetRowConditionExpectation(): void;
    get rowConditionExpectationInput(): GoogleDataplexDatascanDataQualitySpecRulesRowConditionExpectation | undefined;
    private _setExpectation;
    get setExpectation(): GoogleDataplexDatascanDataQualitySpecRulesSetExpectationOutputReference;
    putSetExpectation(value: GoogleDataplexDatascanDataQualitySpecRulesSetExpectation): void;
    resetSetExpectation(): void;
    get setExpectationInput(): GoogleDataplexDatascanDataQualitySpecRulesSetExpectation | undefined;
    private _statisticRangeExpectation;
    get statisticRangeExpectation(): GoogleDataplexDatascanDataQualitySpecRulesStatisticRangeExpectationOutputReference;
    putStatisticRangeExpectation(value: GoogleDataplexDatascanDataQualitySpecRulesStatisticRangeExpectation): void;
    resetStatisticRangeExpectation(): void;
    get statisticRangeExpectationInput(): GoogleDataplexDatascanDataQualitySpecRulesStatisticRangeExpectation | undefined;
    private _tableConditionExpectation;
    get tableConditionExpectation(): GoogleDataplexDatascanDataQualitySpecRulesTableConditionExpectationOutputReference;
    putTableConditionExpectation(value: GoogleDataplexDatascanDataQualitySpecRulesTableConditionExpectation): void;
    resetTableConditionExpectation(): void;
    get tableConditionExpectationInput(): GoogleDataplexDatascanDataQualitySpecRulesTableConditionExpectation | undefined;
    private _uniquenessExpectation;
    get uniquenessExpectation(): GoogleDataplexDatascanDataQualitySpecRulesUniquenessExpectationOutputReference;
    putUniquenessExpectation(value: GoogleDataplexDatascanDataQualitySpecRulesUniquenessExpectation): void;
    resetUniquenessExpectation(): void;
    get uniquenessExpectationInput(): GoogleDataplexDatascanDataQualitySpecRulesUniquenessExpectation | undefined;
}
export declare class GoogleDataplexDatascanDataQualitySpecRulesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleDataplexDatascanDataQualitySpecRules[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataplexDatascanDataQualitySpecRulesOutputReference;
}
export interface GoogleDataplexDatascanDataQualitySpec {
    /**
    * A filter applied to all rows in a single DataScan job. The filter needs to be a valid SQL expression for a WHERE clause in BigQuery standard SQL syntax. Example: col1 >= 0 AND col2 < 10
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#row_filter GoogleDataplexDatascan#row_filter}
    */
    readonly rowFilter?: string;
    /**
    * The percentage of the records to be selected from the dataset for DataScan.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#sampling_percent GoogleDataplexDatascan#sampling_percent}
    */
    readonly samplingPercent?: number;
    /**
    * rules block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#rules GoogleDataplexDatascan#rules}
    */
    readonly rules?: GoogleDataplexDatascanDataQualitySpecRules[] | cdktf.IResolvable;
}
export declare function googleDataplexDatascanDataQualitySpecToTerraform(struct?: GoogleDataplexDatascanDataQualitySpecOutputReference | GoogleDataplexDatascanDataQualitySpec): any;
export declare class GoogleDataplexDatascanDataQualitySpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataplexDatascanDataQualitySpec | undefined;
    set internalValue(value: GoogleDataplexDatascanDataQualitySpec | undefined);
    private _rowFilter?;
    get rowFilter(): string;
    set rowFilter(value: string);
    resetRowFilter(): void;
    get rowFilterInput(): string | undefined;
    private _samplingPercent?;
    get samplingPercent(): number;
    set samplingPercent(value: number);
    resetSamplingPercent(): void;
    get samplingPercentInput(): number | undefined;
    private _rules;
    get rules(): GoogleDataplexDatascanDataQualitySpecRulesList;
    putRules(value: GoogleDataplexDatascanDataQualitySpecRules[] | cdktf.IResolvable): void;
    resetRules(): void;
    get rulesInput(): cdktf.IResolvable | GoogleDataplexDatascanDataQualitySpecRules[] | undefined;
}
export interface GoogleDataplexDatascanExecutionSpecTriggerOnDemand {
}
export declare function googleDataplexDatascanExecutionSpecTriggerOnDemandToTerraform(struct?: GoogleDataplexDatascanExecutionSpecTriggerOnDemandOutputReference | GoogleDataplexDatascanExecutionSpecTriggerOnDemand): any;
export declare class GoogleDataplexDatascanExecutionSpecTriggerOnDemandOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataplexDatascanExecutionSpecTriggerOnDemand | undefined;
    set internalValue(value: GoogleDataplexDatascanExecutionSpecTriggerOnDemand | undefined);
}
export interface GoogleDataplexDatascanExecutionSpecTriggerSchedule {
    /**
    * Cron schedule for running scans periodically. This field is required for Schedule scans.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#cron GoogleDataplexDatascan#cron}
    */
    readonly cron: string;
}
export declare function googleDataplexDatascanExecutionSpecTriggerScheduleToTerraform(struct?: GoogleDataplexDatascanExecutionSpecTriggerScheduleOutputReference | GoogleDataplexDatascanExecutionSpecTriggerSchedule): any;
export declare class GoogleDataplexDatascanExecutionSpecTriggerScheduleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataplexDatascanExecutionSpecTriggerSchedule | undefined;
    set internalValue(value: GoogleDataplexDatascanExecutionSpecTriggerSchedule | undefined);
    private _cron?;
    get cron(): string;
    set cron(value: string);
    get cronInput(): string | undefined;
}
export interface GoogleDataplexDatascanExecutionSpecTrigger {
    /**
    * on_demand block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#on_demand GoogleDataplexDatascan#on_demand}
    */
    readonly onDemand?: GoogleDataplexDatascanExecutionSpecTriggerOnDemand;
    /**
    * schedule block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#schedule GoogleDataplexDatascan#schedule}
    */
    readonly schedule?: GoogleDataplexDatascanExecutionSpecTriggerSchedule;
}
export declare function googleDataplexDatascanExecutionSpecTriggerToTerraform(struct?: GoogleDataplexDatascanExecutionSpecTriggerOutputReference | GoogleDataplexDatascanExecutionSpecTrigger): any;
export declare class GoogleDataplexDatascanExecutionSpecTriggerOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataplexDatascanExecutionSpecTrigger | undefined;
    set internalValue(value: GoogleDataplexDatascanExecutionSpecTrigger | undefined);
    private _onDemand;
    get onDemand(): GoogleDataplexDatascanExecutionSpecTriggerOnDemandOutputReference;
    putOnDemand(value: GoogleDataplexDatascanExecutionSpecTriggerOnDemand): void;
    resetOnDemand(): void;
    get onDemandInput(): GoogleDataplexDatascanExecutionSpecTriggerOnDemand | undefined;
    private _schedule;
    get schedule(): GoogleDataplexDatascanExecutionSpecTriggerScheduleOutputReference;
    putSchedule(value: GoogleDataplexDatascanExecutionSpecTriggerSchedule): void;
    resetSchedule(): void;
    get scheduleInput(): GoogleDataplexDatascanExecutionSpecTriggerSchedule | undefined;
}
export interface GoogleDataplexDatascanExecutionSpec {
    /**
    * The unnested field (of type Date or Timestamp) that contains values which monotonically increase over time. If not specified, a data scan will run for all data in the table.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#field GoogleDataplexDatascan#field}
    */
    readonly field?: string;
    /**
    * trigger block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#trigger GoogleDataplexDatascan#trigger}
    */
    readonly trigger: GoogleDataplexDatascanExecutionSpecTrigger;
}
export declare function googleDataplexDatascanExecutionSpecToTerraform(struct?: GoogleDataplexDatascanExecutionSpecOutputReference | GoogleDataplexDatascanExecutionSpec): any;
export declare class GoogleDataplexDatascanExecutionSpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataplexDatascanExecutionSpec | undefined;
    set internalValue(value: GoogleDataplexDatascanExecutionSpec | undefined);
    private _field?;
    get field(): string;
    set field(value: string);
    resetField(): void;
    get fieldInput(): string | undefined;
    private _trigger;
    get trigger(): GoogleDataplexDatascanExecutionSpecTriggerOutputReference;
    putTrigger(value: GoogleDataplexDatascanExecutionSpecTrigger): void;
    get triggerInput(): GoogleDataplexDatascanExecutionSpecTrigger | undefined;
}
export interface GoogleDataplexDatascanTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#create GoogleDataplexDatascan#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#delete GoogleDataplexDatascan#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan#update GoogleDataplexDatascan#update}
    */
    readonly update?: string;
}
export declare function googleDataplexDatascanTimeoutsToTerraform(struct?: GoogleDataplexDatascanTimeouts | cdktf.IResolvable): any;
export declare class GoogleDataplexDatascanTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataplexDatascanTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleDataplexDatascanTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan google_dataplex_datascan}
*/
export declare class GoogleDataplexDatascan extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_dataplex_datascan";
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.69.1/docs/resources/google_dataplex_datascan google_dataplex_datascan} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleDataplexDatascanConfig
    */
    constructor(scope: Construct, id: string, config: GoogleDataplexDatascanConfig);
    get createTime(): string;
    private _dataProfileResult;
    get dataProfileResult(): GoogleDataplexDatascanDataProfileResultList;
    private _dataQualityResult;
    get dataQualityResult(): GoogleDataplexDatascanDataQualityResultList;
    private _dataScanId?;
    get dataScanId(): string;
    set dataScanId(value: string);
    get dataScanIdInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _executionStatus;
    get executionStatus(): GoogleDataplexDatascanExecutionStatusList;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get state(): string;
    get type(): string;
    get uid(): string;
    get updateTime(): string;
    private _data;
    get data(): GoogleDataplexDatascanDataOutputReference;
    putData(value: GoogleDataplexDatascanData): void;
    get dataInput(): GoogleDataplexDatascanData | undefined;
    private _dataProfileSpec;
    get dataProfileSpec(): GoogleDataplexDatascanDataProfileSpecOutputReference;
    putDataProfileSpec(value: GoogleDataplexDatascanDataProfileSpec): void;
    resetDataProfileSpec(): void;
    get dataProfileSpecInput(): GoogleDataplexDatascanDataProfileSpec | undefined;
    private _dataQualitySpec;
    get dataQualitySpec(): GoogleDataplexDatascanDataQualitySpecOutputReference;
    putDataQualitySpec(value: GoogleDataplexDatascanDataQualitySpec): void;
    resetDataQualitySpec(): void;
    get dataQualitySpecInput(): GoogleDataplexDatascanDataQualitySpec | undefined;
    private _executionSpec;
    get executionSpec(): GoogleDataplexDatascanExecutionSpecOutputReference;
    putExecutionSpec(value: GoogleDataplexDatascanExecutionSpec): void;
    get executionSpecInput(): GoogleDataplexDatascanExecutionSpec | undefined;
    private _timeouts;
    get timeouts(): GoogleDataplexDatascanTimeoutsOutputReference;
    putTimeouts(value: GoogleDataplexDatascanTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleDataplexDatascanTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
